# OLX Brasil Scrapping

[![MIT License](https://img.shields.io/badge/license-MIT-007EC7.svg?style=flat-square)](/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/olxbrasil.svg)](https://pypi.python.org/pypi/olxbrasil)
[![PyPI](https://img.shields.io/pypi/pyversions/olxbrasil.svg)]()
![PyPI - Downloads](https://img.shields.io/pypi/dm/olxbrasil.svg?label=pip%20installs&logo=python)
[![codecov](https://codecov.io/gh/mdslino/olxbrasil/branch/main/graph/badge.svg)](https://codecov.io/gh/mdslino/olxbrasil)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/54968a88b27647f1b47154f942905a5d)](https://www.codacy.com/gh/Mdslino/olxbrasil/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=Mdslino/olxbrasil&amp;utm_campaign=Badge_Grade)
![GitHub issues](https://img.shields.io/github/issues/mdslino/olxbrasil.svg)
![GitHub stars](https://img.shields.io/github/stars/mdslino/olxbrasil.svg)
![GitHub last commit](https://img.shields.io/github/last-commit/mdslino/olxbrasil.svg)
[![Code Style Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black/)
